@@ -13,7 +13,7 @@ PROJ_HEAD(aeqd, "Azimuthal Equidistant")
 PROJ_HEAD(affine, "Affine transformation")
 PROJ_HEAD(airy, "Airy")
 PROJ_HEAD(aitoff, "Aitoff")
-PROJ_HEAD(alsk, "Mod. Stererographics of Alaska")
+PROJ_HEAD(alsk, "Modified Stereographic of Alaska")
 PROJ_HEAD(apian, "Apian Globular I")
 PROJ_HEAD(august, "August Epicycloidal")
 PROJ_HEAD(axisswap, "Axis ordering")
@@ -59,8 +59,8 @@ PROJ_HEAD(gins8, "Ginsburg VIII (TsNIIGAiK)")
 PROJ_HEAD(gn_sinu, "General Sinusoidal Series")
 PROJ_HEAD(gnom, "Gnomonic")
 PROJ_HEAD(goode, "Goode Homolosine")
-PROJ_HEAD(gs48, "Mod. Stererographics of 48 U.S.")
-PROJ_HEAD(gs50, "Mod. Stererographics of 50 U.S.")
+PROJ_HEAD(gs48, "Modified Stereographic of 48 U.S.")
+PROJ_HEAD(gs50, "Modified Stereographic of 50 U.S.")
 PROJ_HEAD(guyou, "Guyou")
 PROJ_HEAD(hammer, "Hammer & Eckert-Greifendorff")
 PROJ_HEAD(hatano, "Hatano Asymmetrical Equal Area")
@@ -73,8 +73,8 @@ PROJ_HEAD(igh,  "Interrupted Goode Homolosine")
 PROJ_HEAD(igh_o,  "Interrupted Goode Homolosine Oceanic View")
 PROJ_HEAD(imw_p, "International Map of the World Polyconic")
 PROJ_HEAD(isea, "Icosahedral Snyder Equal Area")
-PROJ_HEAD(kav5, "Kavraisky V")
-PROJ_HEAD(kav7, "Kavraisky VII")
+PROJ_HEAD(kav5, "Kavrayskiy V")
+PROJ_HEAD(kav7, "Kavrayskiy VII")
 PROJ_HEAD(krovak, "Krovak")
 PROJ_HEAD(labrd, "Laborde")
 PROJ_HEAD(laea, "Lambert Azimuthal Equal Area")
@@ -141,6 +141,7 @@ PROJ_HEAD(qsc, "Quadrilateralized Spherical Cube")
 PROJ_HEAD(robin, "Robinson")
 PROJ_HEAD(rouss, "Roussilhe Stereographic")
 PROJ_HEAD(rpoly, "Rectangular Polyconic")
+PROJ_HEAD(s2, "S2")
 PROJ_HEAD(sch, "Spherical Cross-track Height")
 PROJ_HEAD(set, "Set coordinate value")
 PROJ_HEAD(sinu, "Sinusoidal (Sanson-Flamsteed)")
@@ -155,6 +156,7 @@ PROJ_HEAD(tinshift, "Triangulation based transformation")
 PROJ_HEAD(tissot, "Tissot Conic")
 PROJ_HEAD(tmerc, "Transverse Mercator")
 PROJ_HEAD(tobmerc, "Tobler-Mercator")
+PROJ_HEAD(topocentric, "Geocentric/Topocentric conversion")
 PROJ_HEAD(tpeqd, "Two Point Equidistant")
 PROJ_HEAD(tpers, "Tilted perspective")
 PROJ_HEAD(unitconvert, "Unit conversion")
@@ -168,7 +170,7 @@ PROJ_HEAD(vandg3, "van der Grinten III")
 PROJ_HEAD(vandg4, "van der Grinten IV")
 PROJ_HEAD(vitk1, "Vitkovsky I")
 PROJ_HEAD(vgridshift, "Vertical grid shift")
-PROJ_HEAD(wag1, "Wagner I (Kavraisky VI)")
+PROJ_HEAD(wag1, "Wagner I (Kavrayskiy VI)")
 PROJ_HEAD(wag2, "Wagner II")
 PROJ_HEAD(wag3, "Wagner III")
 PROJ_HEAD(wag4, "Wagner IV")
